@@ -12,11 +12,18 @@ use std::ops::Bound;
 
 use crate::core::Domain;
 use crate::error::Fallible;
+use crate::traits::{CheckNull, TotalOrd};
+use std::fmt::{Debug, Formatter};
 
-/// A Domain that contains all members of the carrier type.
+/// A Domain that contains all non-null members of the carrier type.
 pub struct AllDomain<T> {
     _marker: PhantomData<T>,
 }
+impl<T> Debug for AllDomain<T> {
+    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), std::fmt::Error> {
+        write!(f, "AllDomain()")
+    }
+}
 impl<T> Default for AllDomain<T> {
     fn default() -> Self { Self::new() }
 }
@@ -33,14 +40,14 @@ impl<T> Clone for AllDomain<T> {
 impl<T> PartialEq for AllDomain<T> {
     fn eq(&self, _other: &Self) -> bool { true }
 }
-impl<T> Domain for AllDomain<T> {
+impl<T: CheckNull> Domain for AllDomain<T> {
     type Carrier = T;
-    fn member(&self, _val: &Self::Carrier) -> Fallible<bool> { Ok(true) }
+    fn member(&self, val: &Self::Carrier) -> Fallible<bool> { Ok(!val.is_null()) }
 }
 
 
 /// A Domain that carries an underlying Domain in a Box.
-#[derive(Clone, PartialEq)]
+#[derive(Clone, PartialEq, Debug)]
 pub struct BoxDomain<D: Domain> {
     element_domain: Box<D>
 }
@@ -58,7 +65,7 @@ impl<D: Domain> Domain for BoxDomain<D> {
 
 
 /// A Domain that unwraps a Data wrapper.
-#[derive(Clone, PartialEq)]
+#[derive(Clone, PartialEq, Debug)]
 pub struct DataDomain<D: Domain> {
     pub form_domain: D,
 }
@@ -78,14 +85,18 @@ impl<D: Domain> Domain for DataDomain<D> where
 }
 
 
-/// A Domain that contains all the values in an interval.
+/// A Domain that contains all the values bounded by an interval.
 #[derive(Clone, PartialEq)]
-pub struct IntervalDomain<T> {
+pub struct BoundedDomain<T> {
     lower: Bound<T>,
     upper: Bound<T>,
 }
-impl<T: PartialOrd> IntervalDomain<T> {
-    pub fn new(lower: Bound<T>, upper: Bound<T>) -> Fallible<Self> {
+impl<T: TotalOrd> BoundedDomain<T> {
+    pub fn new_closed(bounds: (T, T)) -> Fallible<Self> {
+        Self::new((Bound::Included(bounds.0), Bound::Included(bounds.1)))
+    }
+    pub fn new(bounds: (Bound<T>, Bound<T>)) -> Fallible<Self> {
+        let (lower, upper) = bounds;
         fn get<T>(value: &Bound<T>) -> Option<&T> {
             match value {
                 Bound::Included(value) => Some(value),
@@ -107,10 +118,15 @@ impl<T: PartialOrd> IntervalDomain<T> {
                 }
             }
         }
-        Ok(IntervalDomain { lower, upper })
+        Ok(BoundedDomain { lower, upper })
     }
 }
-impl<T: Clone + PartialOrd> Domain for IntervalDomain<T> {
+impl<T> Debug for BoundedDomain<T> {
+    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), std::fmt::Error> {
+        write!(f, "BoundedDomain()")
+    }
+}
+impl<T: Clone + TotalOrd> Domain for BoundedDomain<T> {
     type Carrier = T;
     fn member(&self, val: &Self::Carrier) -> Fallible<bool> {
         Ok(match &self.lower {
@@ -127,7 +143,7 @@ impl<T: Clone + PartialOrd> Domain for IntervalDomain<T> {
 
 
 /// A Domain that contains pairs of values.
-#[derive(Clone, PartialEq)]
+#[derive(Clone, PartialEq, Debug)]
 pub struct PairDomain<D0: Domain, D1: Domain>(pub D0, pub D1);
 impl<D0: Domain, D1: Domain> PairDomain<D0, D1> {
     pub fn new(element_domain0: D0, element_domain1: D1) -> Self {
@@ -143,7 +159,7 @@ impl<D0: Domain, D1: Domain> Domain for PairDomain<D0, D1> {
 
 
 /// A Domain that contains maps of (homogeneous) values.
-#[derive(Clone, PartialEq)]
+#[derive(Clone, PartialEq, Debug)]
 pub struct MapDomain<DK: Domain, DV: Domain> where DK::Carrier: Eq + Hash {
     pub key_domain: DK,
     pub value_domain: DV
@@ -153,7 +169,7 @@ impl<DK: Domain, DV: Domain> MapDomain<DK, DV> where DK::Carrier: Eq + Hash {
         MapDomain { key_domain, value_domain: element_domain }
     }
 }
-impl<K, V> MapDomain<AllDomain<K>, AllDomain<V>> where K: Eq + Hash {
+impl<K: CheckNull, V: CheckNull> MapDomain<AllDomain<K>, AllDomain<V>> where K: Eq + Hash {
     pub fn new_all() -> Self {
         Self::new(AllDomain::<K>::new(), AllDomain::<V>::new())
     }
@@ -176,6 +192,11 @@ impl<DK: Domain, DV: Domain> Domain for MapDomain<DK, DV> where DK::Carrier: Eq
 pub struct VectorDomain<D: Domain> {
     pub element_domain: D,
 }
+impl<D: Domain> Debug for VectorDomain<D> {
+    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), std::fmt::Error> {
+        write!(f, "VectorDomain({:?})", self.element_domain)
+    }
+}
 impl<D: Domain + Default> Default for VectorDomain<D> {
     fn default() -> Self { Self::new(D::default()) }
 }
@@ -184,7 +205,7 @@ impl<D: Domain> VectorDomain<D> {
         VectorDomain { element_domain }
     }
 }
-impl<T> VectorDomain<AllDomain<T>> {
+impl<T: CheckNull> VectorDomain<AllDomain<T>> {
     pub fn new_all() -> Self {
         Self::new(AllDomain::<T>::new())
     }
@@ -203,11 +224,16 @@ impl<D: Domain> Domain for VectorDomain<D> {
 #[derive(Clone, PartialEq)]
 pub struct SizedDomain<D: Domain> {
     pub element_domain: D,
-    pub length: usize
+    pub size: usize
 }
 impl<D: Domain> SizedDomain<D> {
-    pub fn new(member_domain: D, length: usize) -> Self {
-        SizedDomain { element_domain: member_domain, length }
+    pub fn new(member_domain: D, size: usize) -> Self {
+        SizedDomain { element_domain: member_domain, size }
+    }
+}
+impl<D: Domain> Debug for SizedDomain<D> {
+    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), std::fmt::Error> {
+        write!(f, "SizedDomain({:?}, size={})", self.element_domain, self.size)
     }
 }
 impl<D: Domain> Domain for SizedDomain<D> {
@@ -232,6 +258,11 @@ impl<D: Domain> InherentNullDomain<D> where D::Carrier: InherentNull {
         InherentNullDomain { element_domain: member_domain }
     }
 }
+impl<D: Domain> Debug for InherentNullDomain<D> where D::Carrier: InherentNull {
+    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), std::fmt::Error> {
+        write!(f, "InherentNullDomain({:?})", self.element_domain)
+    }
+}
 impl<D: Domain> Domain for InherentNullDomain<D> where D::Carrier: InherentNull {
     type Carrier = D::Carrier;
     fn member(&self, val: &Self::Carrier) -> Fallible<bool> {
@@ -239,14 +270,11 @@ impl<D: Domain> Domain for InherentNullDomain<D> where D::Carrier: InherentNull
         self.element_domain.member(val)
     }
 }
-pub trait InherentNull {
-    fn is_null(&self) -> bool;
+pub trait InherentNull: CheckNull {
     const NULL: Self;
 }
 macro_rules! impl_inherent_null_float {
     ($($ty:ty),+) => ($(impl InherentNull for $ty {
-        #[inline]
-        fn is_null(&self) -> bool { self.is_nan() }
         const NULL: Self = Self::NAN;
     })+)
 }
@@ -268,6 +296,11 @@ impl<D: Domain> OptionNullDomain<D> {
         OptionNullDomain { element_domain: member_domain }
     }
 }
+impl<D: Domain> Debug for OptionNullDomain<D> {
+    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), std::fmt::Error> {
+        write!(f, "OptionNullDomain({:?})", self.element_domain)
+    }
+}
 impl<D: Domain> Domain for OptionNullDomain<D> {
     type Carrier = Option<D::Carrier>;
     fn member(&self, value: &Self::Carrier) -> Fallible<bool> {
